==> classpath-0.17.tar.gz: classpath-0.17/org/omg/CORBA/TypeCodePackage/BadKind.java <==
/* BadKind.java --
   Copyright (C) 2005 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package org.omg.CORBA.TypeCodePackage;

import java.io.Serializable;

import org.omg.CORBA.IDLEntity;
import org.omg.CORBA.UserException;

/**
 * This exception is thrown when an inappropriate operation is invoked on
 * a {@link org.omg.CORBA.TypeCode} object.
 *
 * @author Audrius Meskauskas (AudriusA@Bioinformatics.org)
 */
public class BadKind
  extends UserException
  implements IDLEntity, Serializable
{
  /** 
   * Use serialVersionUID for interoperability. 
   */
  private static final long serialVersionUID = 1030443154456771956L;
  
  /**
   * Constructs a the exception.
   */
  public BadKind()
  {
  }

  /**
   * Constructs the exception, explaining the reason of throwing it.
   * @param reason a string, explaining, why the exception has been thrown.
   */
  public BadKind(String reason)
  {
    super(reason);
  }
}

==> classpath-0.90.tar.gz: classpath-0.90/org/omg/CORBA/TypeCodePackage/BadKind.java <==
/* BadKind.java --
   Copyright (C) 2005 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package org.omg.CORBA.TypeCodePackage;

import java.io.Serializable;

import org.omg.CORBA.UserException;
import org.omg.CORBA.portable.IDLEntity;

/**
 * This exception is thrown when an inappropriate operation is invoked on
 * a {@link org.omg.CORBA.TypeCode} object.
 *
 * @author Audrius Meskauskas (AudriusA@Bioinformatics.org)
 */
public class BadKind
  extends UserException
  implements IDLEntity, Serializable
{
  /** 
   * Use serialVersionUID for interoperability. 
   */
  private static final long serialVersionUID = 1030443154456771956L;
  
  /**
   * Constructs a the exception.
   */
  public BadKind()
  {
  }

  /**
   * Constructs the exception, explaining the reason of throwing it.
   * @param reason a string, explaining, why the exception has been thrown.
   */
  public BadKind(String reason)
  {
    super(reason);
  }
}
